@@ -12,10 +12,16 @@ import pyrebase  # Default pyrebase is pyrebase3 which won't work. Need to insta
 from google.cloud.firestore import Client
 from google.oauth2.credentials import Credentials
 import sys
+from unittest.mock import MagicMock
+
 import olorenchemengine
 
 sys.modules["olorenautoml"] = olorenchemengine # important for backwards compatibility of some models
 
+def mock_imports(g, *args):
+    for arg in args:
+        g[arg] = MagicMock()
+
 def all_subclasses(cls):
     """ Helper function to return all subclasses of class"""
     return set(cls.__subclasses__()).union([s for c in cls.__subclasses__() for s in all_subclasses(c)])
@@ -250,6 +256,14 @@ class BaseClass(ABC):
         else:
             return [o for sc in cls.__subclasses__() for o in sc.AllInstances()]
 
+    @classmethod
+    def Opt(cls, *args, **kwargs):
+        return {
+            **{"BC_class_name": cls.__name__},
+            **{"args": args},
+            **{"kwargs": kwargs},
+        }
+
     @abstractmethod
     def _save(self) -> dict:
         """_save is an abstract method that must be implemented by all subclasses. It should return a dictionary of variables which can passed to an instance of a model via _load to completely recreate a model.
