@@ -13,7 +13,10 @@ from .external.stoned import *
 
 import PIL
 
-import selfies as sf
+try:
+    import selfies as sf
+except ImportError:
+    mock_imports(globals(), "sf")
 
 from rdkit.DataStructs.cDataStructs import BulkTanimotoSimilarity, TanimotoSimilarity
 from rdkit import Chem
@@ -25,13 +28,13 @@ class PerturbationEngine(BaseClass):
     into a similar one with a small difference.
 
     Methods:
-        get_compound_at_idx: returns a compound with a modification at a given 
+        get_compound_at_idx: returns a compound with a modification at a given
             atom index
         get_compound: returns a compound with a randomly chosen modification
         get_compound_list: returns a list of compounds with modifications, the list
             is meant to be comprehensive of the result of the application of an
             entire class of modifications."""
-            
+
     @abstractmethod
     def get_compound_at_idx(self, mol: Chem.Mol, idx: int) -> str:
         pass
@@ -63,7 +66,7 @@ class SwapMutations(PerturbationEngine):
         if not radius in (0, 1, 2):
             raise ValueError("radius must be 0, 1, or 2")
 
-        
+
         self.trans = dict()
         for radius in range(radius+1):
             transformation_path = download_public_file(f"swap-mutations/trans_{radius}.json")
@@ -184,7 +187,7 @@ class SwapMutations(PerturbationEngine):
         m = Chem.CombineMols(ref_m, Chem.MolFromSmiles(sub, sanitize=False))
 
         m = Chem.RWMol(m)
-        
+
         removal = []
         for i in range(len(m.GetAtoms())):
             if m.GetAtomWithIdx(i).GetAtomMapNum() == 10000:
@@ -481,183 +484,4 @@ def model_molecule_sensitivity(model: BaseModel, smiles: str, perturbation_engin
         v = np.std(predictions)
         a.SetProp("sensitivity", str(v))
         a.SetProp("atomNote", str(np.format_float_scientific(v, precision=2)))
-    return mol
-
-from PIL import Image
-
-class BaseVis(BaseClass):
-    """Base class for visualizations.
-    """
-    @log_arguments
-    def __init__(self, log=True):
-        pass
-
-    def _run_image(self, *args, **kwargs) -> PIL.Image:
-
-        raise NotImplementedError
-
-    def _run_html(self) -> io.StringIO:
-
-        raise NotImplementedError
-
-    def run(self, display="ipynb", **kwargs):
-        """run is the core method of the `BaseVis` class. It will run and then
-        output the visualization in the specified display format. On the backend
-        it will call one of `_run_image` or `_run_html` method, in order by
-        priority.
-
-        Args:
-            display (str, optional): The format in which to display the output
-            to. Defaults to "ipynb", other options are "html", "image",
-            "save_html", "save_image", where "save_*" requires a filename
-            parameter specifying where to save the output to
-
-        Returns:
-            visualization: Type depends on specified display format.
-        """
-        if display == "ipynb":
-            try:
-                return self._run_image(**kwargs)
-            except NotImplementedError:
-                pass
-            try:
-                from IPython.display import display, HTML
-                return display(HTML(self._run_html(**kwargs).getvalue()))
-            except NotImplementedError:
-                pass
-        elif display == "image":
-            try:
-                return self._run_image(**kwargs)
-            except NotImplementedError:
-                pass
-            try:
-                from IPython.display import display, HTML
-                return display(HTML(self._run_html(**kwargs).getvalue()))
-            except NotImplementedError:
-                pass
-
-
-    def _save(self):
-        pass
-
-    def _load(self, d: dict):
-        pass
-
-def fig_to_PIL(fig):
-    """Converts a plotnine figure to a PIL image.
-
-    Parameters:
-        fig: plotnine figure
-
-    Returns:
-        PIL image generated from plotnine figure
-    """
-    return PIL.Image.frombytes('RGB', fig.canvas.get_width_height(),fig.canvas.tostring_rgb())
-
-class RegressionFeaturesContribution(BaseVis):
-    """Visualization of a regression model and its features.
-    """
-
-    @log_arguments
-    def __init__(self, rep: BaseCompoundVecRepresentation, log=True, **kwargs):
-        self.feat_names = rep.names
-        self.rep = rep
-
-    def _run_image(self, dataset: BaseDataset = None, alpha=0.4, wspace = 0.1, hspace=0.1, regression_fit = False):
-        """_run_image returns a `PIL.Image` of the visualization for given
-        inputs
-
-        Parameters:
-            dataset: dataset to be used for visualization
-            alpha: transparency of the regression line
-            wspace: width space between the regression line and the feature
-            hspace: height space between the regression line and the feature
-            regression_fit: whether to show the regression line
-
-        Returns:
-            PIL image generated from the visualization
-        """
-        assert not dataset is None, "No dataset provided"
-        N = len(self.rep)
-
-        all_feats = self.rep.convert(dataset.entire_dataset[0])
-        col_feats = [[row[i] for row in all_feats] for i in range(len(self.rep))]
-        ys = dataset.entire_dataset[1]
-
-        if regression_fit:
-            GR = oce.GuessingRegression()
-            GR.fit(pd.DataFrame({name: feat for name, feat in zip(self.feat_names, col_feats)}), dataset.entire_dataset[1])
-
-        df = pd.DataFrame(columns=["Feature Name", "Feature Value", "Property"])
-        for i, name in enumerate(self.feat_names):
-            feats = [x[i] for x in all_feats]
-            df2 = pd.DataFrame({"Feature Name": name,
-                "Feature Value": feats,
-                "Property": ys})
-            df = df.append(df2)
-
-        df["Feature Value"] = df["Feature Value"].astype(float)
-        df["Property"] = df["Property"].astype(float)
-        print(df)
-        from plotnine import ggplot, aes, geom_point, facet_wrap, theme, ylab
-        fig = (ggplot(df, aes(x="Feature Value", y="Property")) +
-            geom_point(alpha=alpha) +
-            facet_wrap("Feature Name", scales="free") +
-            theme(subplots_adjust={'wspace':wspace, 'hspace':hspace}) +
-            ylab("% Compounds with Value")).draw()
-
-        fig.canvas.draw()
-        return PIL.Image.frombytes('RGB',
-            fig.canvas.get_width_height(),fig.canvas.tostring_rgb())
-
-class ClassificationFeaturesContribution(BaseVis):
-    """Visualization of a classification model and its features.
-    """
-
-    @log_arguments
-    def __init__(self, rep: BaseCompoundVecRepresentation, log=True, **kwargs):
-        self.feat_names = rep.names
-        self.rep = rep
-
-    def _run_image(self, dataset: BaseDataset = None, alpha=0.4, wspace = 0.1, hspace=0.1):
-        """_run_image returns a `PIL.Image` of the visualization for given
-        inputs
-
-        Parameters:
-            dataset: dataset to be used for visualization
-            alpha: transparency of the regression line
-            wspace: width space between the regression line and the feature
-            hspace: height space between the regression line and the feature
-
-        Returns:
-            PIL image generated for the visualization
-        """
-        assert not dataset is None, "No dataset provided"
-        N = len(self.rep)
-
-        all_feats = self.rep.convert(dataset.entire_dataset[0])
-        col_feats = [[row[i] for row in all_feats] for i in range(len(self.rep))]
-        ys = dataset.entire_dataset[1]
-
-        df = pd.DataFrame(columns=["Feature Name", "Feature Value", "Property"])
-        for i, name in enumerate(self.feat_names):
-            feats = [x[i] for x in all_feats]
-            df2 = pd.DataFrame({"Feature Name": name,
-                "Feature Value": feats,
-                "Property": ys})
-            df = df.append(df2)
-
-        df["Feature Value"] = df["Feature Value"].astype(float)
-        df["Property"] = df["Property"]#.astype(float)
-
-        from plotnine import ggplot, aes, geom_histogram, facet_wrap, theme, ylab
-        fig = (ggplot(df, aes(x="Feature Value", color="Property")) +
-            geom_histogram(aes(y='..width..*..density..'), fill="white", alpha=0.5, position="dodge2", bins=10) +
-            facet_wrap("Feature Name", scales="free", ncol=1) +
-            theme(subplots_adjust={'wspace':wspace, 'hspace':hspace}) +
-            theme(figure_size=(7.5, 3.5*N)) +
-            ylab("% Compounds with Value")).draw()
-
-        fig.canvas.draw()
-        return PIL.Image.frombytes('RGB',
-            fig.canvas.get_width_height(),fig.canvas.tostring_rgb())
\ No newline at end of file
+    return mol
\ No newline at end of file
